@@ -13,17 +13,17 @@ DEFAULT_HISTORIC_DATA_ID = 1000
 DEFAULT_MARKET_DATA_ID = 2000
 
 
-class TDHistoricDataError(LookupError):
+class TDHistoricDataError(Exception):
     def __str__(self):
         return f"{Style.BRIGHT}{Fore.RED}Something's wrong with the historical data...{Style.RESET_ALL}"
 
 
-class TDLiveDataError(LookupError):
+class TDLiveDataError(Exception):
     def __str__(self):
         return f"{Style.BRIGHT}{Fore.RED}Something's wrong with the historical data...{Style.RESET_ALL}"
 
 
-class TDInvalidRequestError(LookupError):
+class TDInvalidRequestError(Exception):
     def __str__(self):
         return f"{Style.BRIGHT}{Fore.RED}Invalid request{Style.RESET_ALL}"
 
@@ -42,7 +42,8 @@ class LiveClient(WebSocketApp):
         self.parent_app = parent_app
 
     def on_open_func(self):
-        print(f"Opening WS...")
+        # print(f"Opening WS...")
+        pass
 
     def on_msg_func(self, message):
         msg = json.loads(message)
@@ -55,9 +56,9 @@ class LiveClient(WebSocketApp):
             pass
 
     def handle_message_data(self, msg):
-        print(f"Truedata has this message for you -> {msg['message']}")
+        # print(f"Truedata has this message for you -> {msg['message']}")
         if msg['message'] == 'TrueData Real Time Data Service':  # Connection success message
-            print(f"You can trade on {msg['segments']}")  # TODO: Format statement better
+            print(f"You have subscribed for {msg['maxsymbols']} symbols across {msg['segments']} until {msg['validity']}...")
         if msg['message'] == 'invalid request':
             print('raising request error')
             raise TDInvalidRequestError
@@ -124,23 +125,23 @@ class HistoricalWebsocket:
         self.historical_port = historical_port
         self.hist_socket = create_connection(f"wss://{self.url}:{self.historical_port}?user={self.login_id}&password={self.password}")
         welcome_msg = self.hist_socket.recv()
-        print(f"Welcomed with '{json.loads(welcome_msg)['message']}'")
+        print(f"Connected successfully to '{json.loads(welcome_msg)['message']}'")
         self.contract_mapping = {}
 
     def get_hist_bar_data(self, contract, query_time, start_time, bar_size):
-        print(f'{{"method": "gethistory", "interval": "{bar_size}", "symbol": "{contract}", "from": "{start_time}", "to": "{query_time}"}}')
+        # print(f'{{"method": "gethistory", "interval": "{bar_size}", "symbol": "{contract}", "from": "{start_time}", "to": "{query_time}"}}')
         self.hist_socket.send(f'{{"method": "gethistory", "interval": "{bar_size}", "symbol": "{contract}", "from": "{start_time}", "to": "{query_time}"}}')
         raw_hist_data = self.hist_socket.recv()
         hist_data = json.loads(raw_hist_data)['data']
-        hist_data = self.hist_data_to_dict_list(hist_data, contract)
+        hist_data = self.hist_bar_data_to_dict_list(hist_data, contract)
         return hist_data
 
     @staticmethod
-    def hist_data_to_dict_list(hist_data, contract):  # No need for symbol other than printing
+    def hist_bar_data_to_dict_list(hist_data, contract):  # No need for symbol other than printing
         data_list = []
         count = 0
         for j in hist_data:
-            try:  # TODO: Remove HOTFIX because of this data point ['2020-02-13T09:15:00', 31565.05, 31565.05, 31565.05, 31565.05, 160, None]
+            try:  # TODO: Remove HOT-FIX because of this data point ['2020-02-13T09:15:00', 31565.05, 31565.05, 31565.05, 31565.05, 160, None]
                 data_list.append({'time': datetime.strptime(j[0], '%Y-%m-%dT%H:%M:%S'),
                                   'o': float(j[1]),
                                   'h': float(j[2]),
@@ -154,8 +155,32 @@ class HistoricalWebsocket:
             count = count + 1
         return data_list
 
-    def get_hist_tick_data(self):
-        pass
+    def get_hist_tick_data(self, contract, query_time, start_time):
+        self.hist_socket.send(f'{{"method": "gethistory", "interval": "tick", "symbol": "{contract}", "from": "{start_time}", "to": "{query_time}"}}')
+        raw_hist_data = self.hist_socket.recv()
+        hist_data = json.loads(raw_hist_data)['data']
+        hist_data = self.hist_tick_data_to_dict_list(hist_data, contract)
+        return hist_data
+
+    @staticmethod
+    def hist_tick_data_to_dict_list(hist_data, contract):
+        data_list = []
+        count = 0
+        for j in hist_data:
+            try:  # TODO: Remove HOT-FIX because of any erroneous data points
+                data_list.append({'time': datetime.strptime(j[0], '%Y-%m-%dT%H:%M:%S'),
+                                  'ltp': float(j[1]),
+                                  'volume': int(j[2]),
+                                  'oi': int(j[3]),
+                                  'bid': float(j[4]),
+                                  'bid_qty': int(j[5]),
+                                  'ask': float(j[6]),
+                                  'ask_qty': int(j[7])})
+            except TypeError:
+                print(f'{Style.BRIGHT}{Fore.RED} {contract} erred with {j}...{Style.RESET_ALL} \n\t {hist_data[count - 2]} \n\t {hist_data[count - 1]} \n\t {hist_data[count]} \n\t {hist_data[count + 1]} \n\t {hist_data[count + 2]}')
+                continue
+            count = count + 1
+        return data_list
 
 
 class TD:
@@ -183,13 +208,11 @@ class TD:
         fyers_append = ''
         if self.fyers_token is not None:
             fyers_append = f'&brokertoken={self.fyers_token}'
-        print(f"\t\t\twss://{self.url}:{self.live_port}?user={self.login_id}&password={self.password}{fyers_append}")
         self.live_websocket = LiveClient(self, f"wss://{self.url}:{self.live_port}?user={self.login_id}&password={self.password}{fyers_append}")
         t = Thread(target=self.connect_thread, args=())
         t.start()
         if self.connect_historical:
             self.historical_websocket = HistoricalWebsocket(self.login_id, self.password, self.url, self.historical_port)
-        print(f'{Fore.GREEN}Connected...{Style.RESET_ALL}')
 
     def connect_thread(self):
         self.live_websocket.run_forever()
@@ -223,6 +246,13 @@ class TD:
                           start_time=None,
                           bar_size="1 min"):
         global DEFAULT_HISTORIC_DATA_ID
+        if (duration is None and start_time is None) or (duration is not None and start_time is not None):
+            # print(f'Using duration over start time due to ambiguity...')
+            return self.get_historical_data_from_duration(contract=contract,
+                                                          ticker_id=ticker_id,
+                                                          query_time=query_time,
+                                                          duration=duration,
+                                                          bar_size=bar_size)
         if duration is not None:
             return self.get_historical_data_from_duration(contract=contract,
                                                           ticker_id=ticker_id,
@@ -230,101 +260,95 @@ class TD:
                                                           duration=duration,
                                                           bar_size=bar_size)
         elif start_time is not None:
-            return self.get_historic_data_from_start_time(contract=contract,
-                                                          ticker_id=ticker_id,
-                                                          query_time=query_time,
-                                                          start_time=start_time,
-                                                          bar_size=bar_size)
+            return self.get_historical_data_from_start_time(contract=contract,
+                                                            ticker_id=ticker_id,
+                                                            query_time=query_time,
+                                                            start_time=start_time,
+                                                            bar_size=bar_size)
 
     def get_historical_data_from_duration(self, contract,
                                           ticker_id=DEFAULT_HISTORIC_DATA_ID,
                                           query_time=None,
-                                          duration="1 D",
+                                          duration=None,
                                           bar_size="1 min"):
         global DEFAULT_HISTORIC_DATA_ID
+        if duration is None:
+            duration = "1 D"
         if query_time is None:
             query_time = datetime.today()
         start_time = self.truedata_duration_map(duration, query_time)
 
+        query_time = query_time.strftime('%Y-%m-%d') + 'T23:59:59'
+        start_time = start_time.strftime('%Y-%m-%d') + 'T00:00:00'
+
         if bar_size == 'tick':
-            hist_data = self.historical_websocket.get_hist_tick_data(contract, )
+            hist_data = self.historical_websocket.get_hist_tick_data(contract, query_time, start_time)
         else:
             bar_size = bar_size.replace(' ', '')
             if bar_size[-1] == 's':
                 bar_size = bar_size[:-1]
-            query_time = query_time.strftime('%Y-%m-%d') + 'T23:59:59'
-            start_time = start_time.strftime('%Y-%m-%d') + 'T00:00:00'
             hist_data = self.historical_websocket.get_hist_bar_data(contract, query_time, start_time, bar_size)
         DEFAULT_HISTORIC_DATA_ID = DEFAULT_HISTORIC_DATA_ID + 1
         self.hist_data[ticker_id] = hist_data
         return hist_data
 
-    def get_historic_data_from_start_time(self, contract,
-                                          ticker_id=DEFAULT_HISTORIC_DATA_ID,
-                                          query_time=None,
-                                          start_time=None,
-                                          bar_size="1 min"):
+    def get_historical_data_from_start_time(self, contract,
+                                            ticker_id=DEFAULT_HISTORIC_DATA_ID,
+                                            query_time=None,
+                                            start_time=None,
+                                            bar_size="1 min"):
         global DEFAULT_HISTORIC_DATA_ID
         if query_time is None:
             query_time = datetime.today()
         if start_time is None:
             start_time = datetime.today()
 
+        query_time = query_time.strftime('%Y-%m-%d') + 'T23:59:59'
+        start_time = start_time.strftime('%Y-%m-%d') + 'T00:00:00'
+
         if bar_size == 'tick':
-            hist_data = self.historical_websocket.get_hist_tick_data(contract, )
+            hist_data = self.historical_websocket.get_hist_tick_data(contract, query_time, start_time)
         else:
             bar_size = bar_size.replace(' ', '')
             if bar_size[-1] == 's':
                 bar_size = bar_size[:-1]
-            query_time = query_time.strftime('%Y-%m-%d') + 'T23:59:59'
-            start_time = start_time.strftime('%Y-%m-%d') + 'T00:00:00'
             hist_data = self.historical_websocket.get_hist_bar_data(contract, query_time, start_time, bar_size)
         DEFAULT_HISTORIC_DATA_ID = DEFAULT_HISTORIC_DATA_ID + 1
         self.hist_data[ticker_id] = hist_data
         return hist_data
 
-    def start_live_data(self, resolved_contract, req_id=None):
+    def start_live_data(self, resolved_contracts, req_id=None):
         global DEFAULT_MARKET_DATA_ID
         if req_id is None:
             req_id = DEFAULT_MARKET_DATA_ID
-        if type(resolved_contract) == str:
-            # self.live_data_contracts[req_id] = resolved_contract
-            self.touchline_data[req_id] = TouchlineData()
-            self.live_data[req_id] = LiveData(resolved_contract)
-            try:
-                self.symbol_mkt_id_map[resolved_contract.upper()].append(req_id)
-            except KeyError:
-                self.symbol_mkt_id_map[resolved_contract.upper()] = [req_id]
-            self.live_websocket.send(f'{{"method": "addsymbol", "symbols": ["{resolved_contract}"]}}')
-            DEFAULT_MARKET_DATA_ID = DEFAULT_MARKET_DATA_ID + 1
-            return req_id
-        elif type(resolved_contract) == list:
-            req_ids = []
-            if type(req_id) == list:
-                if len(req_id) == len(resolved_contract):
-                    req_ids = req_id
-                else:
-                    print(f"{Style.BRIGHT}{Fore.RED}Lengths do not match...{Style.RESET_ALL}")
+
+        req_ids = []
+        if type(req_id) == list:
+            if len(req_id) == len(resolved_contracts):
+                req_ids = req_id
             else:
-                if req_id is None:
-                    curr_req_id = DEFAULT_MARKET_DATA_ID
-                    for i in range(0, len(resolved_contract)):
-                        req_ids.append(curr_req_id + i)
-                    DEFAULT_MARKET_DATA_ID = DEFAULT_MARKET_DATA_ID + len(resolved_contract)
-                else:
-                    curr_req_id = req_id
-                    for i in range(0, len(resolved_contract)):
-                        req_ids.append(curr_req_id + i)
-            for j in range(0, len(req_ids)):
-                print(j)
-                self.touchline_data[req_ids[j]] = TouchlineData()
-                self.live_data[req_ids[j]] = LiveData(resolved_contract[j])
-                try:
-                    self.symbol_mkt_id_map[resolved_contract[j].upper()].append(req_ids[j])
-                except KeyError:
-                    self.symbol_mkt_id_map[resolved_contract[j].upper()] = [req_ids[j]]
-                self.live_websocket.send(f'{{"method": "addsymbol", "symbols": ["{resolved_contract[j]}"]}}')
-            return req_ids
+                print(f"{Style.BRIGHT}{Fore.RED}Lengths do not match...{Style.RESET_ALL}")
+        elif req_id is None:
+            curr_req_id = DEFAULT_MARKET_DATA_ID
+            for i in range(0, len(resolved_contracts)):
+                req_ids.append(curr_req_id + i)
+            DEFAULT_MARKET_DATA_ID = DEFAULT_MARKET_DATA_ID + len(resolved_contracts)
+        elif type(req_id) == int:
+            curr_req_id = req_id
+            for i in range(0, len(resolved_contracts)):
+                req_ids.append(curr_req_id + i)
+        else:
+            print(f"{Style.BRIGHT}{Fore.RED}Invalid req_id datatype...{Style.RESET_ALL}")
+            raise TDLiveDataError
+        for j in range(0, len(req_ids)):
+            self.touchline_data[req_ids[j]] = TouchlineData()
+            self.live_data[req_ids[j]] = LiveData(resolved_contracts[j])
+            try:
+                self.symbol_mkt_id_map[resolved_contracts[j].upper()].append(req_ids[j])
+            except KeyError:
+                self.symbol_mkt_id_map[resolved_contracts[j].upper()] = [req_ids[j]]
+        self.live_websocket.send(f'{{"method": "addsymbol", "symbols": {json.dumps(resolved_contracts)}}}')
+        return req_ids
 
     def stop_live_data(self, contract):
         self.live_websocket.send(f'{{"method": "removesymbol", "symbols": ["{contract}"]}}')
