@@ -55,45 +55,45 @@ def run_historical_tests(td_app_ip, symbols):
     tick_hist_data_3 = td_app_ip.get_historic_data(f'{symbol}', bar_size='tick', start_time=test_time-relativedelta(days=3))
 
     print(f'{Style.BRIGHT}{Fore.BLUE}------------- HIST BAR DATA TEST RESULTS -------------{Style.RESET_ALL}')
-    print(f'{Style.BRIGHT}{Fore.BLUE}HISTDATA 1...{Style.RESET_ALL}')
-    print(f"Command used -> hist_data_1 = td_app.get_historic_data('{symbol}')")
-    print(f'LENGTH OF RESULT = {len(hist_data_1)}')
+    print(f"{Style.BRIGHT}{Fore.BLUE}HISTDATA 1...\n"
+          f"\tCommand used -> hist_data_1 = td_app.get_historic_data('{symbol}')\n"
+          f"\tLENGTH OF RESULT = {len(hist_data_1)}{Style.RESET_ALL}")
     for hist_point in hist_data_1[-20:]:
         print(hist_point)
-    print(f'{Style.BRIGHT}{Fore.BLUE}HISTDATA 2...{Style.RESET_ALL}')
-    print(f"Command used -> hist_data_2 = td_app.get_historic_data('{symbol}', duration='3 D')")
-    print(f'LENGTH OF RESULT = {len(hist_data_2)}')
+    print(f"{Style.BRIGHT}{Fore.BLUE}HISTDATA 2...\n"
+          f"\tCommand used -> hist_data_2 = td_app.get_historic_data('{symbol}', duration='3 D')\n"
+          f"\tLENGTH OF RESULT = {len(hist_data_2)}{Style.RESET_ALL}")
     for hist_point in hist_data_2[-20:]:
         print(hist_point)
-    print(f'{Style.BRIGHT}{Fore.BLUE}HISTDATA 3...{Style.RESET_ALL}')
-    print(f"Command used -> hist_data_3 = td_app.get_historic_data('{symbol}', duration='3 D', bar_size='15 mins')")
-    print(f'LENGTH OF RESULT = {len(hist_data_3)}')
+    print(f"{Style.BRIGHT}{Fore.BLUE}HISTDATA 3...\n"
+          f"\tCommand used -> hist_data_3 = td_app.get_historic_data('{symbol}', duration='3 D', bar_size='15 mins')\n"
+          f"\tLENGTH OF RESULT = {len(hist_data_3)}{Style.RESET_ALL}")
     for hist_point in hist_data_3[-20:]:
         print(hist_point)
-    print(f'{Style.BRIGHT}{Fore.BLUE}HISTDATA 4...{Style.RESET_ALL}')
-    print(f"Command used -> hist_data_4 = td_app.get_historic_data('{symbol}', bar_size='30 mins')")
-    print(f'LENGTH OF RESULT = {len(hist_data_4)}')
+    print(f"{Style.BRIGHT}{Fore.BLUE}HISTDATA 4...)\n"
+          f"\tCommand used -> hist_data_4 = td_app.get_historic_data('{symbol}', bar_size='30 mins')\n"
+          f"\tLENGTH OF RESULT = {len(hist_data_4)}{Style.RESET_ALL}")
     for hist_point in hist_data_4[-20:]:
         print(hist_point)
-    print(f'{Style.BRIGHT}{Fore.BLUE}HISTDATA 5...{Style.RESET_ALL}')
-    print(f"Command used -> hist_data_5 = td_app.get_historic_data('{symbol}', bar_size='30 mins', start_time={test_time - relativedelta(days=3)})")
-    print(f'LENGTH OF RESULT = {len(hist_data_5)}')
+    print(f"{Style.BRIGHT}{Fore.BLUE}HISTDATA 5...\n"
+          f"\tCommand used -> hist_data_5 = td_app.get_historic_data('{symbol}', bar_size='30 mins', start_time={test_time - relativedelta(days=3)})\n"
+          f"\tLENGTH OF RESULT = {len(hist_data_5)}{Style.RESET_ALL}")
     for hist_point in hist_data_5[-20:]:
         print(hist_point)
     print(f'{Style.BRIGHT}{Fore.BLUE}------------- HIST TICK DATA TEST RESULTS -------------{Style.RESET_ALL}')
-    print(f'{Style.BRIGHT}{Fore.BLUE}TICKDATA 1...{Style.RESET_ALL}')
-    print(f"Command used -> tick_data_1 = td_app.get_historic_data('{symbol}', bar_size='tick')")
-    print(f'LENGTH OF RESULT = {len(tick_hist_data_1)}')
+    print(f"{Style.BRIGHT}{Fore.BLUE}TICKDATA 1...\n"
+          f"\tCommand used -> tick_data_1 = td_app.get_historic_data('{symbol}', bar_size='tick')\n"
+          f"\tLENGTH OF RESULT = {len(tick_hist_data_1)}{Style.RESET_ALL}")
     for hist_point in tick_hist_data_1[-20:]:
         print(hist_point)
-    print(f'{Style.BRIGHT}{Fore.BLUE}TICKDATA 2...{Style.RESET_ALL}')
-    print(f"Command used -> tick_data_2 = td_app.get_historic_data('{symbol}', bar_size='tick', duration='3 D')")
-    print(f'LENGTH OF RESULT = {len(tick_hist_data_2)}')
+    print(f"{Style.BRIGHT}{Fore.BLUE}TICKDATA 2...\n"
+          f"\tCommand used -> tick_data_2 = td_app.get_historic_data('{symbol}', bar_size='tick', duration='3 D')\n"
+          f"\tLENGTH OF RESULT = {len(tick_hist_data_2)}{Style.RESET_ALL}")
     for hist_point in tick_hist_data_2[-20:]:
         print(hist_point)
-    print(f'{Style.BRIGHT}{Fore.BLUE}TICKDATA 3...{Style.RESET_ALL}')
-    print(f"Command used -> tick_data_3 = td_app.get_historic_data('{symbol}', bar_size='tick', start_time={test_time - relativedelta(days=3)})")
-    print(f'LENGTH OF RESULT = {len(tick_hist_data_3)}')
+    print(f"{Style.BRIGHT}{Fore.BLUE}TICKDATA 3...\n"
+          f"\tCommand used -> tick_data_3 = td_app.get_historic_data('{symbol}', bar_size='tick', start_time={test_time - relativedelta(days=3)})\n"
+          f"\tLENGTH OF RESULT = {len(tick_hist_data_3)}{Style.RESET_ALL}")
     for hist_point in tick_hist_data_3[-20:]:
         print(hist_point)
 
@@ -117,7 +117,8 @@ def run_live_tests(td_app_ip, symbols):
     print(f"{Style.BRIGHT}{Fore.BLUE}Here's the touchline data...{Style.RESET_ALL}")
     for req_id in req_ids:
         print(td_app_ip.touchline_data[req_id])
-    count = 0
+    print()
+    print(f"{Style.BRIGHT}{Fore.BLUE}Here's the LIVE stream...{Style.RESET_ALL}")
     live_data_objs = {}
     for req_id in req_ids:    
         live_data_objs[req_id] = deepcopy(td_app_ip.live_data[req_id])
